pub mod error;
pub mod media_server;

use error::handle_rejection;
use std::path::PathBuf;

use clap::Parser as _;
use tracing::Level;
use warp::Filter;

#[derive(clap::Parser, Clone)]
pub struct Args {
    music_dir: PathBuf,
}

#[tokio::main]
async fn main() {
    let config: &'static Args = Box::leak(Box::new(Args::parse()));

    tracing_subscriber::fmt().with_max_level(Level::INFO).init();

    let route = warp::path("media").and(media_server::serve_local_tracks(&config.music_dir));

    warp::serve(route.recover(handle_rejection))
        .run(([127, 0, 0, 1], 8080))
        .await;
}
